package org.springblade.core.sms;

import com.github.qcloudsms.SmsMultiSender;
import com.github.qcloudsms.SmsMultiSenderResult;
import com.github.qcloudsms.httpclient.HTTPException;
import org.springblade.core.sms.model.SmsCode;
import org.springblade.core.sms.model.SmsData;
import org.springblade.core.sms.model.SmsResponse;
import org.springblade.core.sms.props.SmsProperties;
import org.springblade.core.tool.utils.Func;
import org.springblade.core.tool.utils.RedisUtil;
import org.springblade.core.tool.utils.StringUtil;
import org.springframework.http.HttpStatus;

import java.io.IOException;
import java.time.Duration;
import java.util.Collection;
import java.util.concurrent.TimeUnit;

/**
 * Author pangqijun
 * Date 2023/10/24
 * Description
 */
public class TencentSmsTemplate implements SmsTemplate {
	private static final int SUCCESS = 0;
	private static final String NATION_CODE = "86";
	private final SmsProperties smsProperties;
	private final SmsMultiSender smsSender;
	private final RedisUtil redisUtil;


	@Override
	public SmsResponse sendMessage(SmsData smsData, Collection<String> phones) {
		try {
			Collection<String> values = smsData.getParams().values();
			String[] params = StringUtil.toStringArray(values);
			SmsMultiSenderResult senderResult = this.smsSender.sendWithParam("86", StringUtil.toStringArray(phones), Func.toInt(this.smsProperties.getTemplateId()), params, this.smsProperties.getSignName(), "", "");
			return new SmsResponse(senderResult.result == 0, senderResult.result, senderResult.toString());
		} catch (IOException | HTTPException var6) {
			var6.printStackTrace();
			return new SmsResponse(Boolean.FALSE, HttpStatus.INTERNAL_SERVER_ERROR.value(), var6.getMessage());
		}
	}
	@Override
	public SmsCode sendValidate(SmsData smsData, String phone) {
		SmsCode smsCode = new SmsCode();
		boolean temp = this.sendSingle(smsData, phone);
		if (temp && StringUtil.isNotBlank(smsData.getKey())) {
			String id = StringUtil.randomUUID();
			String value = (String)smsData.getParams().get(smsData.getKey());
			this.redisUtil.set(this.cacheKey(phone, id), value, 30L, TimeUnit.MINUTES);
			smsCode.setId(id).setValue(value);
		} else {
			smsCode.setSuccess(Boolean.FALSE);
		}

		return smsCode;
	}
	@Override
	public boolean validateMessage(SmsCode smsCode) {
		String id = smsCode.getId();
		String value = smsCode.getValue();
		String phone = smsCode.getPhone();
		String cache = (String)this.redisUtil.get(this.cacheKey(phone, id));
		if (StringUtil.isNotBlank(value) && StringUtil.equalsIgnoreCase(cache, value)) {
			this.redisUtil.del(this.cacheKey(phone, id));
			return true;
		} else {
			return false;
		}
	}

	public TencentSmsTemplate(final SmsProperties smsProperties, final SmsMultiSender smsSender, final RedisUtil redisUtil) {
		this.smsProperties = smsProperties;
		this.smsSender = smsSender;
		this.redisUtil = redisUtil;
	}
}
