package org.springblade.core.sms;

import com.yunpian.sdk.YunpianClient;
import com.yunpian.sdk.model.Result;
import com.yunpian.sdk.model.SmsBatchSend;
import org.springblade.core.sms.model.SmsCode;
import org.springblade.core.sms.model.SmsData;
import org.springblade.core.sms.model.SmsResponse;
import org.springblade.core.sms.props.SmsProperties;
import org.springblade.core.tool.support.Kv;
import org.springblade.core.tool.utils.PlaceholderUtil;
import org.springblade.core.tool.utils.RedisUtil;
import org.springblade.core.tool.utils.StringUtil;

import java.time.Duration;
import java.util.Collection;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * Author pangqijun
 * Date 2023/10/25
 * Description
 */
public class YunpianSmsTemplate implements SmsTemplate {
	private final SmsProperties smsProperties;
	private final YunpianClient client;
	private final RedisUtil redisUtil;

	@Override
	public SmsResponse sendMessage(SmsData smsData, Collection<String> phones) {
		String templateId = this.smsProperties.getTemplateId();
		String templateText = PlaceholderUtil.getResolver("#", "#").resolveByMap(templateId, Kv.create().setAll(smsData.getParams()));
		Map<String, String> param = this.client.newParam(2);
		param.put("mobile", StringUtil.join(phones));
		param.put("text", templateText);
		Result<SmsBatchSend> result = this.client.sms().multi_send(param);
		return new SmsResponse(result.getCode() == 0, result.getCode(), result.toString());
	}

	@Override
	public SmsCode sendValidate(SmsData smsData, String phone) {
		SmsCode smsCode = new SmsCode();
		boolean temp = this.sendSingle(smsData, phone);
		if (temp && StringUtil.isNotBlank(smsData.getKey())) {
			String id = StringUtil.randomUUID();
			String value = smsData.getParams().get(smsData.getKey());
			this.redisUtil.set(this.cacheKey(phone, id), value, 30L, TimeUnit.MINUTES);
			smsCode.setId(id).setValue(value);
		} else {
			smsCode.setSuccess(Boolean.FALSE);
		}
		return smsCode;
	}

	@Override
	public boolean validateMessage(SmsCode smsCode) {
		String id = smsCode.getId();
		String value = smsCode.getValue();
		String phone = smsCode.getPhone();
		String cache = (String)this.redisUtil.get(this.cacheKey(phone, id));
		if (StringUtil.isNotBlank(value) && StringUtil.equalsIgnoreCase(cache, value)) {
			this.redisUtil.del(this.cacheKey(phone, id));
			return true;
		} else {
			return false;
		}
	}

	public YunpianSmsTemplate(final SmsProperties smsProperties, final YunpianClient client, final RedisUtil redisUtil) {
		this.smsProperties = smsProperties;
		this.client = client;
		this.redisUtil = redisUtil;
	}
}
